#ifndef INSTANTIATE_TEMPLATES
#include <vepl/vepl_convert.txx>
template vil_image_resource vepl_convert(vil_image_resource_sptr, int);
#endif
